@@ -1,7 +1,7 @@
 package Device::Temperature::TMP102;
 use Moose;
 
-our $VERSION = '0.0.6'; # VERSION
+our $VERSION = '0.0.7'; # VERSION
 
 extends 'Device::SMBus';
 
@@ -10,24 +10,6 @@ has '+I2CDeviceAddress' => (
     default => 0x48,
 );
 
-has 'TMP_RD' => (
-    is => 'ro',
-    isa => 'Num',
-    default => 0x93,
-);
-
-has 'TMP_RW' => (
-    is => 'ro',
-    isa => 'Num',
-    default => 0x92,
-);
-
-has 'TMP_REG' => (
-    is => 'ro',
-    isa => 'Num',
-    default => 0x72,
-);
-
 has debug => (
     is      => 'ro',
     default => 0,
@@ -36,12 +18,16 @@ has debug => (
 sub getTemp {
     my ( $self ) = @_;
 
-    my $results = $self->readWordData( $self->TMP_REG );
+    my $results = $self->readWordData( $self->I2CDeviceAddress );
 
     unless ( $results ) {
         die( "ERROR: failed to get temperature reading" );
     }
 
+    if ( $results eq "-1" ) {
+        die( "ERROR: got back an error code from I2C Device" );
+    }
+
     return $self->convertTemp( $results );
 }
 
@@ -82,22 +68,6 @@ sub convertTemp {
     return $temp;
 }
 
-sub _set_pointer_register {
-    my ( $self ) = @_;
-
-    # We want to write a value to the TMP
-    $self->writeByte( $self->TMP_RW );
-
-    # Set pointer regster to temperature register (it's already there
-    # by default, but you never know)
-    $self->writeByte( $self->TMP_REG );
-
-    # Read from this I2C address, R/*W Set
-    $self->writeByte( $self->TMP_RD );
-
-    return 1;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
